import tkinter as tk


class Kinds:
    def __init__(self, master, *args, **kwargs):
        self.master = master

        self.imethods = tk.PhotoImage(data="""iVBORw0KGgoAAAANSUhEUgAAAA8AAAAPCAYAAAA71pVKAAAACXBIWXMAAA7DAAAOwwHHb6hk
        AAAAGXRFWHRTb2Z0d2FyZQB3d3cuaW5rc2NhcGUub3Jnm+48GgAAAddJREFUKJGNkjFrk3EQxn/3vtEW8QMICoK
        CNZYqDn4BndQ2NIMZRHES0TqILomW9toG7aJiW4cOQkGKoAhNagUHEZwspHQQm9SiDoI4iBqJJNb3/Z9D+0IaE+
        iz3d3z4+7gEZpoLru0OwjkDpAE5p3H5eRAfKHRJ/XF5GRhy46v2y9hNmxITiCNcCqqfeRqj3Z8+w/Oa+kouAlDq
        oL1JfTAm2j2VFd2+YQ3PeykiQwvWse4qjhZA5eyhlxAuL5o+x+oimv2Tn5o+biZGxMoJjSe8AAMuQJUzPg9qFgz
        cM1nNYGyQc8zfb/HW+/7AvcFRvJaKswOvTtWD80MF7vyWprD7IkTmwYqq4QxAchpseog/hf3pU38i5j1AwXDbnv
        IaYOUIRNGdTSph3/mtFgO4UisfkNKO1eBe49HP0y111bTIC8MHlksiPf2d31ufMNrbACk0nvLCY1ngKrzY4PNwJ
        bwZhXBoeC2bQZ4pZ/aAX8rfrAO213Be50bKp5XtZbXzOjSiV/U3gIvu3Xfxw0JM2wcqEUJy2mx4vzYIRfyp2XCI
        j0fW2kLvgfXDDIC0wbnwKZAzoA99NuCG92Zgz8i/wY40mx2eWcY2C3BzgosOM/19Q50zjf6/gEMUNa2RFgfkAAA
        AABJRU5ErkJggg==""")
        self.ivariables = None
        self.ifields = tk.PhotoImage(data="""iVBORw0KGgoAAAANSUhEUgAAAA8AAAANCAYAAAB2HjRBAAAACX
        BIWXMAAA7DAAAOwwHHb6hkAAAAGXRFWHRTb2Z0d2FyZQB3d3cuaW5rc2NhcGUub3Jnm+48GgAAAcBJREFUKJF1k
        jFoUwEQhr97SQzaqODi5KCTRRA3K6iQxA5BnIpZHCwIioJK074XqEZSi2hIK0gpilBBcNStVMX4nkWtFDqVLi5F
        wUlECBrRNu/9Tq0xbW68+7/j/uM3OtSQr8MOlAQ5jPkoYnQ8a89bNbYBqumIGcMYPSYmYwkmm01yghLQMHGrmuE
        pZlqH3ZqO4XADOGgwts24X07bz7X5+QUldv7gLGLY4HsUcdncQIeAu4huQTXV4EH5lP3qaGdWey1kBkjFEc8Mmq
        HoGc/a505Q0deBEFxC+gxmBHkH2CfjoxlLnq+H3qy6W6HB1zru+ZqO4D3wNRT7V1e4CBAHaP6hP5lkRyiuEPLB8
        /UOMS2jH9gjuOeEnKn0Wh1g4IV2rcMAd9L2CSgUX2kkinEVYwK40PWNJ+W8rWxmxWlvVHqt3hRTwGo1Y4/awYE5
        bU1s4Ryw7ABfYklOlwPF2xf99+WX6hryVYj/ZllGDqMvroi84zDRAM8NdLu+ncfU/0HlQKmGuAQMAotE5Ksn7C2
        sJUwy9w0nESVgt2DK4JrBiKAALDhitJK1udZrNsSzGOhoBDcRaaAmuD6WsfnNrPwFMR6ziXNIHQ8AAAAASUVORK
        5CYII=""")
        self.iclasses = tk.PhotoImage(data="""iVBORw0KGgoAAAANSUhEUgAAAA8AAAAPCAYAAAA71pVKAAAAC
        XBIWXMAAA7DAAAOwwHHb6hkAAAAGXRFWHRTb2Z0d2FyZQB3d3cuaW5rc2NhcGUub3Jnm+48GgAAAdFJREFUKJGN
        0k1IVFEYxvH/c+descDgzsaCFhHUeDPBatcmIheCIi2slasZpDZB22hTBrWqhSEhzUdRIAxB1KpshJYRtTAoxgp
        qYYILvVMimDP3vK2KYZSxZ3U4nN/Lw8sRTYlLvf3mkgpmlXBx35iuvW7QJt7fQ60YHTeXVIA7SFG8f7lkZVI74j
        h/5JgzmxVcT+eqN801hpCN1taikbY4LvX2m9ysZBNhrnrXyr0d8vx7oHf1De9VO+ybS+aA22F2YfJb6UBnvJY8B
        XZvBsHg3tyH9VawUsyM4tSX3lOd0Go+eoSsz/luyGt4eWBQsrNhduFZK1wtZsYwTQGLwLysTCr+FT1ANgq8BdLA
        T0lLzdCZ+YIzeN6wkuSUSZcFYGVStbVo5HcQzHbUN+dM/BD25Z80pYFxTMMShwy7KtyAtlQr9LyR7FZzbZs+EcT
        ++hOgD+gSbiDMfZ73WvF20YX39bArdQ5ZwWDEl1uCpk+y44DzHzelXVPAZN3873Ehc9rf7qGh7lrx8MHmu4Sg09
        zGY0EVrGzo+RZs8EnGtGspJRKAGZmumKgAD7csbLss3z/aHXiNr0g3MBsHXobZ6qX/wgArxZ6TMl4AM2G2elHC/
        gCskr1TRm4JBAAAAABJRU5ErkJggg==""")
        self.iinterfaces = tk.PhotoImage(data="""iVBORw0KGgoAAAANSUhEUgAAAA8AAAAICAYAAAAm06XyAA
        AACXBIWXMAAA7DAAAOwwHHb6hkAAAAGXRFWHRTb2Z0d2FyZQB3d3cuaW5rc2NhcGUub3Jnm+48GgAAAQRJREFUG
        JWFkD9LgnEAhJ/7qbODQw211JLRVlMEofYFgqIhglpsqSnfCJeaChRXgz5Aa30A/1ARCbnXJ7Aai5rC95oEkcAb
        D4577sQYFbtOpb+IMLuIKeBJCQ4qq3pJAkRNzwoylTzPSB4Opz+pI5YtIsf0QmDDfTrRnZdUantfpg4EzG21oPV
        BsNT2gsx9KiZ7vqaPgR+1fYHJKmr5DZgcKrsGvgEEc8B7Ja+tYZqjhudDoBPGbf5PyYAAkoJTwyUQEDfVnLZHsB
        /KDU8MY/fNjqApgJOGZ34hUyvQHT3suOUrmxUFysT0HNjEFBNiUeMQz9pO/sSUJPYM08BjLA5rOb3+AQBaXk0WW
        bcyAAAAAElFTkSuQmCC""")
        self.imodules = tk.PhotoImage(data="""iVBORw0KGgoAAAANSUhEUgAAAA8AAAAPCAYAAAA71pVKAAAAC
        XBIWXMAAA7DAAAOwwHHb6hkAAAAGXRFWHRTb2Z0d2FyZQB3d3cuaW5rc2NhcGUub3Jnm+48GgAAAXtJREFUKJGN
        0TuLE2EYxfH/eZLIikkweEFb2xQWostMOhUCUwha+BG0007wEwh22ilabmNpF1CbZCbeECzS2iqsMrmJu2bzvBa
        OQkJMfMr3nB8ceEVxnU7nSLVavQ9cb7VaJ1i6NE13gWfT6fROu93+DmB/wlqt9gC4FEK4uQwBJN0ALha9328Ag8
        Hg0HA4HJnZ5SiK0lUYoN/vt9z9xWg0Opokyb4B5Hl+HNiazWaf/gUBinyrXq8fW5gNYGZah5dzAyiVSqeAAzPLN
        +AcOAghnAZQmqbngYeSduM4vrIOA2RZ9hw4CdwqA2+Bubuf3QQB3P2upI/AG5O0Lem9md37H1z03gEXBNDtds+Z
        2WtJ9TiOf6yZfDiEMDaz7SiKPhiApM9A2d0bGyY3gPJ8Pv8CS1/l7mEDXsgNYDwefwP2KpXKmXW4yPcajcbXvzh
        Jkn1JO+7+JMuyq6tgr9e75u5PJe00m82fC7Mnk8lt4FUI4fEqLOkR8LLoAfALta2R2TiY6xMAAAAASUVORK5CYI
        I=""")
        self.iproperties = tk.PhotoImage(data="""iVBORw0KGgoAAAANSUhEUgAAAA8AAAAPCAYAAAA71pVKAA
        AACXBIWXMAAA7DAAAOwwHHb6hkAAAAGXRFWHRTb2Z0d2FyZQB3d3cuaW5rc2NhcGUub3Jnm+48GgAAAdFJREFUK
        JGN0r9rFEEUB/Dvd+8uxzUhoBCCEkhtEbTbHVdZIiQQfySKWmkjWtkIWtj4D1imsDQIRlCDoBbauOLNzR5aGrBV
        EY0g2gQCtzfztTALinenrxt4n++8Nwwxorrd7ni/379O8gyAKQDvAdwyxqwAQDQCTnrvLcndJBcBnAewC0Be9Qz
        F3vubJJ8aYy6GEGYkrZBcMMZsWGv3WWsvcxDM83xibGzsQ6/X29NoNPaTfExyPkmS1+12ezaKoucAfgy8udVqTZ
        P8lGXZVlmW7yR9BLBYFMUBks9IXgEwM2zsr5Km8jyvZ1n2rSzLuRDCUgjhhaRLkt4C2ByIvfezANBsNicBoAqQt
        Jym6RNJ1wCs/7VzURRHQgh3oyg6Gcdxx1o7XZbl5yzL+t1ud9x7fwPA0RBC/Ad2zs1JWvsNZiQfAQgANgHsBfCQ
        5NUkSb7XK2itzSStSToVx3GnCgJwnOSG936iVqt9SZJkuzLcgQdJrocQzqZp+tI5d1jS/eo85FHBTqdzCMADAKe
        NMa+cc/OS7lSjD4MAUAdwG8C5HbggaRXAUhzHxSgI/PqeLUnbzrllSashhBPGmH9CAKhLukDynqQtAMfSNH3zPx
        AAfgL2/u9cQzl88QAAAABJRU5ErkJggg==""")
        self.ikeywords = tk.PhotoImage(data="""iVBORw0KGgoAAAANSUhEUgAAAA8AAAAPCAYAAAA71pVKAAAA
        CXBIWXMAAA7DAAAOwwHHb6hkAAAAGXRFWHRTb2Z0d2FyZQB3d3cuaW5rc2NhcGUub3Jnm+48GgAAAPRJREFUKJG
        lkrFKxEAURc8bHltbWqytYG0TYiC2VnZ+hK3iByhouX7HfkcmhAgigpXFgt02gpXETObZiEVMWI23PecOl+HBPy
        Le+5cxaGaLLMsWY1yBHRE5NLO3Hrtwzm0BFEVxJCI3Q2XM7BIIPbYLPAOo6n2M8exHWUROxmaFEJ4AkiRZA+sxb
        1KkLMvrTVKM8SHLsmVVVfMY4ynwnqbplZrZbFPZOacATdOIqs7MrP8/E2Z774+HQAjhMc/zFUBVVfOu6/b7jgLn
        Q2VVvQVWXw/ticigNzlS1/X2b+UQwkeapq/f69q2Hb3tgdwBB39ZN5pP4uJac+7GJRAAAAAASUVORK5CYII=""")
        self.iwords = tk.PhotoImage(data="""iVBORw0KGgoAAAANSUhEUgAAAA8AAAAICAYAAAAm06XyAAAACXB
        IWXMAAA7DAAAOwwHHb6hkAAAAGXRFWHRTb2Z0d2FyZQB3d3cuaW5rc2NhcGUub3Jnm+48GgAAATBJREFUGJWFjy
        FLQ2EYhc95t31JEQYiGExaLBODYbvJaFBEGBqHGNW4n6BFBUGw2ZUJCoaxMGT3Xm+1LwkLgrILwzLZdwy7wTD0i
        ec9z4EXmEAcx40wDPcn3X5j/xX+gmEYLgA4JLkE4KFSqdzEcdwA0Jc0A0CSzoMgSNrt9pRzrg5gRVLXSNZIfki6
        AnDa6XRKGBsbku5IPpNsJkky55x7AjAv6ZLkV344HJ4VCoUdM9uUNMrlcsuZfBEEwS0ARFG0670/BrDY6/XWq9X
        qCEAr75xrABgAeASwKilHElmGbIgkpwF8ZuL45yiKUgCBpG+SLwCOSG5LmvXebwEomdk9yTVJife+ViwWm/1+f9
        tI1iW1ssIrgIGkd0lmZm9mdk1yr1wudwFUzewkTdOU5MEPhImOHsSTJnYAAAAASUVORK5CYII=""")
